<?php

//
// +---------------------------------------------------------------------------+
// | Inmemoriam v 1.0 plug-in for Geeklog                                      |
// | install.php                                                               |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2005 by the following authors:                              |
// | Author: Alf Deeley aka machinari - ajdeeley@summitpages.ca                |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

require_once('../../../lib-common.php');
require_once($_CONF['path'] . 'plugins/inmemoriam/config.php');
require_once($_CONF['path'] . 'plugins/inmemoriam/functions.inc');

//
// install variables
//

$pi_name = $INM_CONF['pi_name'];        // Plugin name  Must be 15 chars or less
$pi_version = $INM_CONF['version'];     // Plugin Version
$gl_version = '1.3.11';                 // GL Version plugin for
$pi_url = 'http://summitpages.ca';      // Plugin Homepage

//
// Default data
// Insert table name and sql to insert default data for your plugin.
//
$DEFVALUES = array();
$DEFVALUES['settings'] = "INSERT INTO {$INM_TABLES['settings']} VALUES (10, 1, 1, 1, 10, 1, 1, 1, 1, 2, 2, 128000, 1, 0)";
$DEFVALUES['phpblock'] = "INSERT INTO {$_TABLES['blocks']} SET is_enabled='0', name='inmrandom', type='phpblock', title='{$LANG_INM01[36]}', tid='all', blockorder='0', onleft='1', phpblockfn='phpblock_inm_randommedia', group_id='4', owner_id='2'";

//
// Security Feature to add
//

$NEWFEATURE = array();
$NEWFEATURE['inmemoriam.admin']     = "inmemoriam Admin Rights";
$NEWFEATURE['inmemoriam.create']    = "inmemoriam Create Album Rights";
$NEWFEATURE['inmemoriam.add']       = "inmemoriam Add Media Rights";
$NEWFEATURE['inmemoriam.fullview']  = "inmemoriam Full View Access";
$NEWFEATURE['inmemoriam.view']      = "inmemoriam Media Gallery Access";


// Only let Root users access this page
if (!SEC_inGroup('Root')) {
    // Someone is trying to illegally access this page
    COM_errorLog("Someone has tried to illegally access the inmemoriam install/uninstall page.  User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR",1);
    $display = COM_siteHeader();
    $display .= COM_startBlock($LANG_INM00['access_denied']);
    $display .= $LANG_INM00['access_denied_msg'];
    $display .= COM_endBlock();
    $display .= COM_siteFooter(true);
    echo $display;
    exit;
}
 
/**
* Puts the datastructures for this plugin into the Geeklog database
* Note: Corresponding uninstall routine is in functions.inc
* 
* @return   boolean True if successful False otherwise
*
*/
function plugin_install_inmemoriam()
{
    global $pi_name, $pi_version, $gl_version, $pi_url, $NEWTABLE, $DEFVALUES, $NEWFEATURE;
    global $_TABLES, $_CONF, $INM_TABLES;

    COM_errorLog("Attempting to install the $pi_name Plugin",1);

    // Create the Plugins Tables
    
    require_once($_CONF['path'] . 'plugins/inmemoriam/sql/sql_install.php');
    for ($i = 1; $i <= count($_SQL); $i++) {
        $progress .= "executing " . current($_SQL) . "<br>\n";
        COM_errorLOG("executing " . current($_SQL));
        DB_query(current($_SQL),'1');
        if (DB_error()) {
            COM_errorLog("Error Creating $table table",1);
            plugin_uninstall_inmemoriam('DeletePlugin');
            return false;
            exit;
        }
        next($_SQL);
    }
    COM_errorLog("Success - Created $table table",1);
    
    // Insert Default Data
    
    foreach ($DEFVALUES as $table => $sql) {
        COM_errorLog("Inserting default data into $table table",1);
        DB_query($sql,1);
        if (DB_error()) {
            COM_errorLog("Error inserting default data into $table table",1);
            plugin_uninstall_inmemoriam();
            return false;
            exit;
        }
        COM_errorLog("Success - inserting data into $table table",1);
    }
    
    // Create the plugin admin security group
    COM_errorLog("Attempting to create $pi_name admin group", 1);
    DB_query("INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr) "
        . "VALUES ('$pi_name Admin', 'Users in this group can administer the $pi_name plugin')",1);
    if (DB_error()) {
        plugin_uninstall_inmemoriam();
        return false;
        exit;
    }
    COM_errorLog('...success',1);
    $group_id = DB_insertId();
    
    // Save the grp id for later uninstall
    COM_errorLog('About to save group_id to vars table for use during uninstall',1);
    DB_query("INSERT INTO {$_TABLES['vars']} VALUES ('{$pi_name}_gid', $group_id)",1);
    if (DB_error()) {
        plugin_uninstall_inmemoriam();
        return false;
        exit;
    }
    COM_errorLog('...success',1);
    
    // Add plugin Features
    foreach ($NEWFEATURE as $feature => $desc) {
        COM_errorLog("Adding $feature feature",1);
        DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
            . "VALUES ('$feature','$desc')",1);
        if (DB_error()) {
            COM_errorLog("Failure adding $feature feature",1);
            plugin_uninstall_inmemoriam();
            return false;
            exit;
        }
        $feat_id = DB_insertId();
        COM_errorLog("Success",1);
        COM_errorLog("Adding $feature feature to admin group",1);
        DB_query("INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($feat_id, $group_id)");
        if (DB_error()) {
            COM_errorLog("Failure adding $feature feature to admin group",1);
            plugin_uninstall_inmemoriam();
            return false;
            exit;
        }
        COM_errorLog("Success",1);
    }        

    // OK, now give Root users access to this plugin now! NOTE: Root group should always be 1
    COM_errorLog("Attempting to give all users in Root group access to $pi_name admin group",1);
    DB_query("INSERT INTO {$_TABLES['group_assignments']} VALUES ($group_id, NULL, 1)");
    if (DB_error()) {
        plugin_uninstall_inmemoriam();
        return false;
        exit;
    }

    // Register the plugin with Geeklog
    COM_errorLog("Registering $pi_name plugin with Geeklog", 1);
    DB_delete($_TABLES['plugins'],'pi_name',$pi_name);
    DB_query("INSERT INTO {$_TABLES['plugins']} (pi_name, pi_version, pi_gl_version, pi_homepage, pi_enabled) "
        . "VALUES ('$pi_name', '$pi_version', '$gl_version', '$pi_url', 1)");

    if (DB_error()) {
        plugin_uninstall_inmemoriam();
        return false;
        exit;
    }

    COM_errorLog("Succesfully installed the $pi_name Plugin!",1);
    return true;
}

/* 
* Main Function
*/

$display = COM_siteHeader();
$T = new Template($_CONF['path'] . 'plugins/inmemoriam/templates');
$T->set_file('install', 'install.thtml');
$T->set_var('install_header', $LANG_INM00['install_header']);
$T->set_var('img',$INM_CONF['url_html'] . '/images/inmemoriam.gif');
$T->set_var('cgiurl', $_CONF['site_admin_url'] . '/plugins/inmemoriam/install.php');
$T->set_var('admin_url', $_CONF['site_admin_url'] . '/plugins/inmemoriam/index.php');
$T->set_var('plugin_admin_url', $_CONF['site_admin_url'] . '/plugins.php' );

if ($_GET['action'] == 'install') {
    if (plugin_install_inmemoriam()) {
        $install_msg = sprintf($LANG_INM00['install_success'],$INM_CONF['url_html'] . '/albums.php?mode=create');
        $T->set_var('installmsg1',$install_msg);
        //$T->set_var('installmsg1',$LANG_INM00['install_success']);
        $T->set_var('editor',$LANG_INM00['editor']);
    } else {
        $T->set_var('installmsg1',$LANG_INM00['install_failed']);
    }
} else if ($_GET['action'] == 'uninstall') {
   plugin_uninstall_inmemoriam('installed');
   $T->set_var('installmsg1',$LANG_INM00['uninstall_msg']);
}

if (DB_count($_TABLES['plugins'], 'pi_name', 'inmemoriam') == 0) {
    $T->set_var('installmsg2', $LANG_INM00['uninstalled']);
    $T->set_var('readme', $LANG_INM00['readme']);
    $T->set_var('installdoc', $LANG_INM00['installdoc']);
    $T->set_var('btnmsg', $LANG_INM00['install']);
    $T->set_var('action','install');
} else {
    $T->set_var('installmsg2', $LANG_INM00['installed']);
    $T->set_var('btnmsg', $LANG_INM00['uninstall']);
    $T->set_var('editor',$LANG_INM00['editor']);
    $T->set_var('action','uninstall');
}
$T->parse('output','install');
$display .= $T->finish($T->get_var('output'));
$display .= COM_siteFooter(true);

echo $display;

?>