<?PHP

//
// +---------------------------------------------------------------------------+
// | Inmemoriam v 1.0 plug-in for Geeklog                                      |
// | image-functions.inc                                                       |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2005 by the following authors:                              |
// | Author: Alf Deeley aka machinari - ajdeeley@summitpages.ca                |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

/*
*quick fix for geeklog's pear path not included in php.ini
*/
if ($_CONF['have_pear']){
    $curPHPIncludePath = ini_get( 'include_path' );
    if( defined( 'PATH_SEPARATOR' )){
        $separator = PATH_SEPARATOR;
    } else {
        // prior to PHP 4.3.0, we have to guess the correct separator ...
        $separator = ';';
        if( strpos( $curPHPIncludePath, $separator ) === false ){
            $separator = ':';
        }
    }
    if( ini_set( 'include_path', $_CONF['path_pear'] . $separator . $curPHPIncludePath ) === false ){
        COM_errorLog( 'ini_set failed - there may be problems using the PEAR image_transform class.', 1);
    }
}



require_once ('Image/Transform.php');


//returns a default image with courtesy info...
function inm_courtesyImage($path = '', $size = ''){
    global $_CONF,$INM_CONF, $LANG_INM01;
    
    if (empty($path)){
        $path = $INM_CONF['path_html'] . 'images/splash.jpg';
    }

    error_reporting(E_ALL);
    $library = inm_imageLib();

    //$image = new Image_Transform();
    $image = Image_Transform::factory($library);
    $image->load($path);

    //add courtesy info
    $text = $LANG_INM01[48] . $_CONF['site_name'];
    $position = 2;//top-center

    /* the following attempts to make use of the image transform package
     * but unless your php is compiled using --with-tllib[=DIR] then your
     * out of luck
     */
    inm_watermarkImage($image, 'txt_mark', $text, '2', $position, 100);

    if (!empty($size)){
        $image->scale($size);
    }

    //display the full image without compression
    $image->display(null, 100);

    // Now free the memory
    $image->free();
}

//fixes spaces in windows path--necessary for IM and NetPBM libs to function
function inm_replaceWinSpaces($path){
    //
    return $path;
}

// returns the proper image library to use
function inm_imageLib(){
    global $_CONF;
    if (!empty ($_CONF['image_lib'])) {
        if ($_CONF['image_lib'] == 'imagemagick') {
            // Using imagemagick
            $library = 'IM';
        } elseif ($_CONF['image_lib'] == 'netpbm') {
            // using netPBM
            $library = 'NetPBM';
        } elseif ($_CONF['image_lib'] == 'gdlib') {
            // using the GD library
            $library = 'GD';
        }
    } else {
        //will attempt to use 'Imagick' first,
        //then 'GD' second, then 'Imlib' last
        $library = '';
    }
    return $library;
}

function inm_thumbnail($path, $size = '85'){
    global $INM_CONF;
    error_reporting(E_ALL);
    $library = inm_imageLib();

    //$thumb = new Image_Transform();
    $thumb = Image_Transform::factory($library);

    $thumb->load($path);

    // next will resize so that the longest edge equals $size preserving aspect ratio
    $thumb->scale($size);
    //display the resized image

    $extension = substr(strrchr($path, '.'),1);
    $thumb->display($extension, $INM_CONF['thumb_quality']);

    /* if using a png image, imagepng() doesn't like the empty $filename so I've had to
       modify Image/Transform/Driver/GD.php.  Of course this only applies to the gdlib */

    // Now free the memory
    $thumb->free();
}

function inm_constrainedImage($path, $maxX = '640', $maxY = '640', $quality = '', $img_mark = '', $txt_mark = '', $size = '', $position = '', $opacity = ''){
    global $INM_CONF;
    error_reporting(E_ALL);
    $library = inm_imageLib();

    //$image = new Image_Transform();
    $image = Image_Transform::factory($library);

    $image->load($path);

    //watermark if called for
    if (!empty($img_mark)){
        inm_watermarkImage($image, 'img_mark', $img_mark, $size, $position, $opacity);
    } elseif (!empty($txt_mark)){
        inm_watermarkImage($image, 'txt_mark', $txt_mark, $size, $position, $opacity);
    }

    // resize so that image remains constrained by max width and height while preserving aspect ratio
    // if image smaller then restrictions--then no resize
    $image->fit($maxX,$maxY);

    //display the resized image
    if (empty($quality)){
        $quality = $INM_CONF['scaled_quality'];
    }
    $extension = substr(strrchr($path, '.'),1);
    $image->display($extension, $quality);

    // Now free the memory
    $image->free();
}

function inm_fullSizeImage($path, $img_mark = '', $txt_mark = '', $size = '', $position = '', $opacity = ''){
    error_reporting(E_ALL);
    $library = inm_imageLib();

    //$image = new Image_Transform();
    $image = Image_Transform::factory($library);

    $image->load($path);

    //watermark if called for
    if (!empty($img_mark)){
        inm_watermarkImage($image, 'img_mark', $img_mark, $size, $position, $opacity);
    } elseif (!empty($txt_mark)){
        inm_watermarkImage($image, 'txt_mark', $txt_mark, $size, $position, $opacity);
    }

    //display the full image without compression
    $extension = substr(strrchr($path, '.'),1);
    $image->display($extension, 100);

    // Now free the memory
    $image->free();
}

//adds a watermark to image
//type is a string or an image
//mark is the text string or the path to an image
/*
* IMPORTANT
* Watermark your images with caution.
* Only the GD functions are performing as desired.
* Imagemagick currently overwrites your original image and 
* NetPBM will overwrite your original if I finish the function. ;)
* This applies to image marks only... Overlaying text shouldn't be a problem.
*/
function inm_watermarkImage(&$image, $type, $mark, $size = 2, $position = 2, $opacity = 100){
    global $INM_CONF, $_CONF, $LANG_INM08;
    error_reporting(E_ALL);

    //get image dimensions for source
    $src_w  = $image->getImageWidth();
    $src_h  = $image->getImageHeight();
    //get dimensions for watermark
    $wm_a   = inm_reportImageSize($INM_CONF['path_wm'],$mark);
    $wm_w   = $wm_a[0];
    $wm_h   = $wm_a[1];

    if ($type == 'img_mark' && !empty($mark)){

        //opacity
        switch ($opacity){
            case 1:
                $opacity = 25;
                break;
            case 3:
                $opacity = 75;
                break;
            case 4:
                $opacity = 100;
                break;
            case 2:
                //50
            default:
                $opacity = 50;
                break;
        }

/*
        //this will have to wait until the pear package is significantly more advanced
        //resize the watermark
        //plan: class should be able to load multiple images and work on them separately
        switch ($size){
            case 2:
                //66%
                $wm_w = $wm_a[0] * '.66';
                $wm_h = $wm_a[1] * '.66';
                break;
            case 3:
                //33%
                $wm_w = $wm_a[0] * '.33';
                $wm_h = $wm_a[1] * '.33';
                break;
            case 1:
                //original size
            default:
                $wm_w = $wm_a[0];
                $wm_h = $wm_a[1];
        }
*/

        //position of the watermark on the original image
        switch ($position){
            case 2:
                // top-center
                $pos_y = 5;
                $pos_x = ($src_w / 2) - ($wm_w / 2);
                break;
            case 3:
                // top-right
                $pos_y = 5;
                $pos_x = ($src_w - $wm_w) - 5;
                break;
            case 4:
                // center-left
                $pos_y = ($src_h / 2) - ($wm_h / 2);
                $pos_x = 5;
                break;
            case 5:
                // center-center
                $pos_y = ($src_h / 2) - ($wm_h / 2);
                $pos_x = ($src_w / 2) - ($wm_w / 2);
                break;
            case 6:
                // center-right
                $pos_y = ($src_h / 2) - ($wm_h / 2);
                $pos_x = ($src_w - $wm_w) - 5;
                break;
            case 7:
                // bottom-left
                $pos_y = ($src_h - $wm_h) - 5;
                $pos_x = 5;
                break;
            case 8:
                // bottom-center
                $pos_y = ($src_h - $wm_h) - 5;
                $pos_x = ($src_w / 2) - ($wm_w / 2);
                break;
            case 9:
                // bottom-right
                $pos_y = ($src_h - $wm_h) - 5;
                $pos_x = ($src_w - $wm_w) - 5;
                break;
            case 1:
                //default
            default:
                // top-left
                $pos_y = 5;
                $pos_x = 5;
                break;
        }

        $mark = $INM_CONF['path_wm'] . $mark;
        $params = array(
                'mark'          => $mark,
                'pos_x'         => $pos_x,
                'pos_y'         => $pos_y,
                'wm_w'          => $wm_w,
                'wm_h'          => $wm_h,
                'opacity'       => $opacity,
                'resize_first'  => false);
        $image->addImage($params);

    } elseif ($type == 'txt_mark' && !empty($mark)){

        //font
        $font = $INM_CONF['font'];
        //font color
        $color = 'gray';
        //shadow color
        $shadow = 'black';

        //set font size for text
        //depending on your system, font size will be in pixel size or in point size.
        switch ($size){
            case 3:
                $txtsize = 24;
                break;
            case 2:
                $txtsize = 16;
                break;
            case 1:
                //12
            default:
                $txtsize = 12;
        }

        //position of the text on the original image
        //position for txt will have to be reworked.
        //have function in mind but won't be implemented till pear package evolves
        switch ($position){
            case 2:
                // top-center
                $txt_y = $txtsize + 5;
                $txt_x = $src_w / 4;//not accurate without bounding box size, but will do for now.
                break;
            case 3:
                // top-right
                $txt_y = $txtsize + 5;
                $txt_x = $src_w / 2;//txt begins center
                break;
            case 4:
                // center-left
                $txt_y = ($src_h / 2) - ($txtsize / 2);
                $txt_x = 5;
                break;
            case 5:
                // center-center
                $txt_y = ($src_h / 2) - ($txtsize / 2);
                $txt_x = $src_w / 4;//txt begins at 25%
                break;
            case 6:
                // center-right
                $txt_y = ($src_h / 2) - ($txtsize / 2);
                $txt_x = $src_w / 2;//txt begins center
                break;
            case 7:
                // bottom-left
                $txt_y = $src_h - 5;
                $txt_x = 5;
                break;
            case 8:
                // bottom-center
                $txt_y = $src_h - 5;
                $txt_x = $src_w / 4;//txt begins at 25%
                break;
            case 9:
                // bottom-right
                $txt_y = $src_h - 5;
                $txt_x = $src_w / 2;//txt begins center
                break;
            case 1:
                //default
            default:
                // top-left
                $txt_y = $txtsize + 5;
                $txt_x = 5;
                break;
        }

        //mark
        switch ($mark){
            case 1:
                //site name
                $mark = $LANG_INM08[80];
                break;
            case 2:
                //site slogan
                $mark = $LANG_INM08[81];
                break;
            case 3:
                //copyright
                $mark = $LANG_INM08[82];
                break;
            case 4:
                //current date/time
                $gldate = COM_getUserDateTimeFormat();
                $mark = $gldate[0];
                break;
            default:
                //site name
                $mark = $mark;
        }

        //drop shadow on text
        $params = array(
                'text'      => $mark,
                'x'         => $txt_x + 1,
                'y'         => $txt_y + 1,
                'color'     => $shadow,
                'font'      => $font,
                'size'      => $txtsize,
                'opacity'   => $opacity,//not being used yet
                'resize_first' => false);
        $image->addText($params);

        //text
        $params = array(
                'text'      => $mark,
                'x'         => $txt_x,
                'y'         => $txt_y,
                'color'     => $color,
                'font'      => $font,
                'size'      => $txtsize,
                'opacity'   => $opacity,//not being used yet
                'resize_first' => false);
        $image->addText($params);
    }
}

//reads and returns a static image
function inm_staticImage($path){
    error_reporting(E_ALL);
    $library = inm_imageLib();

    //$image = new Image_Transform();
    $image = Image_Transform::factory($library);

    $image->load($path);

    //display the full image without compression
    $extension = substr(strrchr($path, '.'),1);
    $image->display($extension, 100);

    // Now free the memory
    $image->free();
}

//read media file into display
function inm_readfile($path){
    global $_CONF, $INM_CONF;

    $extension = strtolower(strrchr($path, '.'));
    if (array_key_exists($extension, $INM_CONF['image_ext'])){
        $mimetype = $INM_CONF['image_ext'][$extension];
    } elseif (array_key_exists($extension, $INM_CONF['aud_ext'])){
        $mimetype = $INM_CONF['aud_ext'][$extension];
    } elseif (array_key_exists($extension, $INM_CONF['vid_ext'])){
        $mimetype = $INM_CONF['vid_ext'][$extension];
    } elseif (array_key_exists($extension, $INM_CONF['cod_ext'])){
        $mimetype = $INM_CONF['cod_ext'][$extension];
    }

    header("Content-type: " . $mimetype, false);

    header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
    header("Cache-Control: no-store, no-cache, must-revalidate");
    header("Cache-Control: post-check=0, pre-check=0", false);
    header("Pragma: no-cache");

/*
    $media = @readfile($path);
    if ($media){
        return $media;
    } else return false;
*/
/*
 * This next bit will, in many cases, solve problems with timeouts and memory limits
 * when dealing with large file sizes.
 * This is only called when audio, video, and documents are being called.
 */
    $chunksize = 1*(1024*1024);// how many bytes per chunk
    $buffer = '';
    $handle = fopen($path, 'rb');
    if ($handle === false) {
        return false;
    }
    while (!feof($handle)) {
        set_time_limit(20);
        $buffer = fread($handle, $chunksize);
        print $buffer;
    }
    return fclose($handle);

}


?>